@@ -105,6 +105,12 @@ public class WorkSpaceSelectionCard extends WizardCard {
 				Log.debug("WorkspaceExplorer Aborted");
 
 			}
+
+			@Override
+			public void onNotValidSelection() {
+				thisCard.saveResourceSession.setItemId(null);
+				
+			}
 		};
 
 		wpanel.addWorkspaceExplorerSelectNotificationListener(handler);
